ScoConnectionParameters

Struct ScoConnectionParameters 

pub struct ScoConnectionParameters {
    pub parameter_set: Option<HfpParameterSet>,
    pub air_coding_format: Option<AssignedCodingFormat>,
    pub air_frame_size: Option<u16>,
    pub io_bandwidth: Option<u32>,
    pub io_coding_format: Option<AssignedCodingFormat>,
    pub io_frame_size: Option<u16>,
    pub io_pcm_data_format: Option<SampleFormat>,
    pub io_pcm_sample_payload_msb_position: Option<u8>,
    pub path: Option<DataPath>,
    pub max_tx_data_size: Option<u16>,
    /* private fields */
}

Fields

parameter_set: Option<HfpParameterSet>

Set of SCO parameters from the Hands-Free Profile specification. Required.

air_coding_format: Option<AssignedCodingFormat>

The over-the-air coding format used for transmitted and received data. Required.

air_frame_size: Option<u16>

Frame size produced by the codec in the context of over-the-air coding. Required.

io_bandwidth: Option<u32>

Host-controller data rate in bytes/second. Required.

io_coding_format: Option<AssignedCodingFormat>

The coding format used over the transport. Required.

io_frame_size: Option<u16>

The number of bits in each sample/frame of data. Required.

io_pcm_data_format: Option<SampleFormat>

The data format over the transport for linear samples. Ignored for non-linear coding formats. Optional. SIGNED indicates 2’s complement sign encoding. FLOAT is not supported.

io_pcm_sample_payload_msb_position: Option<u8>

For linear samples, indicates how many bit positions the MSB of the sample is away from the MSB of the data. Ignored for non-linear coding formats. Optional. Default: 0.

path: Option<DataPath>

The data transport. Required.

max_tx_data_size: Option<u16>

Indicates the maximum data buffer size that may be sent. Optional. Only present after a connection has successfully been connected. Ignored when requesting a connection.